@@ -15,7 +15,9 @@ from selenium.webdriver.common.keys import Keys
 from selenium.webdriver.support.ui import WebDriverWait
 from selenium.common.exceptions import WebDriverException
 from selenium.webdriver.support import expected_conditions as EC
+from selenium.webdriver.firefox.service import Service as FirefoxService
 
+from webdriver_manager.firefox import GeckoDriverManager
 # error handling
 # from selenium.common.exceptions import NoSuchElementException
 
@@ -72,21 +74,27 @@ webdrivers = {
         "options": webdriver.firefox.options.Options(),
         # "profile": firefox_profile,
         "url": "https://github.com/mozilla/geckodriver/releases",
+        "kwargs": {
+            "service": FirefoxService(GeckoDriverManager().install())
+        }
     },
     "chrome": {
         "webdriver": webdriver.Chrome,
         "options": webdriver.chrome.options.Options(),
         "url": "https://chromedriver.chromium.org/downloads",
+        "kwargs" : {}
     },
     "safari": {
         "driver": webdriver.Safari,
         "options": webdriver.safari.options.Options(),
         "url": "https://webkit.org/blog/6900/webdriver-support-in-safari-10/",
+        "kwargs" : {}
     },
     "edge": {
         "driver": webdriver.Edge,
         "options": webdriver.edge.options.Options(),
         "url": "https://developer.microsoft.com/en-us/microsoft-edge/tools/webdriver/",  # noqa E501
+        "kwargs" : {}
     },
 }
 
@@ -105,6 +113,7 @@ class Crawler:  # pylint: disable=too-many-public-methods
         browser: str = "firefox",
         headless: bool = False,
         quit_on_failure: bool = True,
+        **kwargs
     ) -> None:
         """
         Parameters
@@ -116,13 +125,13 @@ class Crawler:  # pylint: disable=too-many-public-methods
             GUI's browser, by default False
         """
         if browser not in webdrivers:
-            message = f"Unsuported browser '{browser}'."
-            message += " List of suported ones: "
+            message = f"Unsupported browser '{browser}'."
+            message += " List of supported ones: "
             message += ", ".join(list(webdrivers.keys())) + "."
             raise CrawlerError(message)
         self.__browser = browser
         self.__driver = None
-        self.__options = None
+        self.__options = Noneexecutable_path="."
         self.__logger = log(self.__class__.__name__)
         self.timeout = 50
         self.quit_on_failure = quit_on_failure
@@ -132,7 +141,7 @@ class Crawler:  # pylint: disable=too-many-public-methods
             if headless:
                 self.__options.headless = True
             driver = webdrivers[browser]["webdriver"]
-            self.__driver = driver(options=self.__options)
+            self.__driver = driver(options=self.__options, **webdrivers[browser]["kwargs"])
         except WebDriverException as err:
             message = "You need to add the driver"
             message += f" for {browser} to your environment variables."
@@ -203,7 +212,7 @@ class Crawler:  # pylint: disable=too-many-public-methods
         self.driver.set_window_rect(x=0, y=0, width=960, height=960)
 
     @quitdriver
-    def element(self, value: str, by_attribue: str = "id") -> list:
+    def element(self, value: str, by_attribute: str = "id") -> list:
         """
         element method.
 
@@ -229,7 +238,7 @@ class Crawler:  # pylint: disable=too-many-public-methods
         """
         wait = WebDriverWait(self.driver, self.timeout)
         element = wait.until(
-            EC.presence_of_element_located((ATTR_SELECTOR[by_attribue], value))
+            EC.presence_of_element_located((ATTR_SELECTOR[by_attribute], value))
         )
         return element
 
@@ -283,6 +292,13 @@ class Crawler:  # pylint: disable=too-many-public-methods
         )
         return elements
 
+    # @quitdriver
+    # def get_attribute(self, element, attribute):
+    #     wait = WebDriverWait(self.driver, self.timeout)
+    #     elements = wait.until(
+    #         EC.((ATTR_SELECTOR[by_attribute], value))
+    #     )
+
     @quitdriver
     def child_of(
         self, element: WebDriver, value: str, by_attribute: str = "id"
